.. highlight:: shell

============
Contributing
============

Report Bugs
-----------

Report bugs at https://github.com/gmagno/nfe_parser/issues.

If you are reporting a bug, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.
